from . import Router as Router
from .const import DOMAIN as DOMAIN
from homeassistant.components.notify import ATTR_TARGET as ATTR_TARGET, BaseNotificationService as BaseNotificationService
from homeassistant.const import CONF_RECIPIENT as CONF_RECIPIENT, CONF_URL as CONF_URL
from homeassistant.helpers.typing import HomeAssistantType as HomeAssistantType
from typing import Any

_LOGGER: Any

async def async_get_service(hass: HomeAssistantType, config: dict[str, Any], discovery_info: Union[dict[str, Any], None]=...) -> Union[HuaweiLteSmsNotificationService, None]: ...

class HuaweiLteSmsNotificationService(BaseNotificationService):
    router: Router = ...
    default_targets: list[str] = ...
    def send_message(self, message: str=..., **kwargs: Any) -> None: ...
    def __init__(self, router: Any, default_targets: Any) -> None: ...
    def __lt__(self, other: Any) -> Any: ...
    def __le__(self, other: Any) -> Any: ...
    def __gt__(self, other: Any) -> Any: ...
    def __ge__(self, other: Any) -> Any: ...
