from .const import DATA_CONNECTIONS as DATA_CONNECTIONS, SIGNAL_WEBSOCKET_CONNECTED as SIGNAL_WEBSOCKET_CONNECTED, SIGNAL_WEBSOCKET_DISCONNECTED as SIGNAL_WEBSOCKET_DISCONNECTED
from homeassistant.components.sensor import SensorEntity as SensorEntity
from homeassistant.core import callback as callback
from typing import Any, Optional

async def async_setup_platform(hass: Any, config: Any, async_add_entities: Any, discovery_info: Optional[Any] = ...) -> None: ...

class APICount(SensorEntity):
    count: int = ...
    def __init__(self) -> None: ...
    async def async_added_to_hass(self) -> None: ...
    @property
    def name(self): ...
    @property
    def state(self): ...
    @property
    def unit_of_measurement(self): ...
    def _update_count(self) -> None: ...
