import yaml
from typing import Any

class NodeListClass(list): ...
class NodeStrClass(str): ...

class Input:
    name: str
    @classmethod
    def from_node(cls: Any, loader: yaml.Loader, node: yaml.nodes.Node) -> Input: ...
    def __init__(self, name: Any) -> None: ...
