from typing import Any

MAJOR_VERSION: int
MINOR_VERSION: int
PATCH_VERSION: str
__short_version__: Any
__version__: Any
REQUIRED_PYTHON_VER: Any
REQUIRED_NEXT_PYTHON_VER: Any
REQUIRED_NEXT_PYTHON_DATE: str
PLATFORM_FORMAT: str
MATCH_ALL: str
ENTITY_MATCH_NONE: str
ENTITY_MATCH_ALL: str
DEVICE_DEFAULT_NAME: str
SUN_EVENT_SUNSET: str
SUN_EVENT_SUNRISE: str
CONF_ABOVE: str
CONF_ACCESS_TOKEN: str
CONF_ADDRESS: str
CONF_AFTER: str
CONF_ALIAS: str
CONF_ALLOWLIST_EXTERNAL_URLS: str
CONF_API_KEY: str
CONF_API_TOKEN: str
CONF_API_VERSION: str
CONF_ARMING_TIME: str
CONF_AT: str
CONF_ATTRIBUTE: str
CONF_AUTH_MFA_MODULES: str
CONF_AUTH_PROVIDERS: str
CONF_AUTHENTICATION: str
CONF_BASE: str
CONF_BEFORE: str
CONF_BELOW: str
CONF_BINARY_SENSORS: str
CONF_BRIGHTNESS: str
CONF_BROADCAST_ADDRESS: str
CONF_BROADCAST_PORT: str
CONF_CHOOSE: str
CONF_CLIENT_ID: str
CONF_CLIENT_SECRET: str
CONF_CODE: str
CONF_COLOR_TEMP: str
CONF_COMMAND: str
CONF_COMMAND_CLOSE: str
CONF_COMMAND_OFF: str
CONF_COMMAND_ON: str
CONF_COMMAND_OPEN: str
CONF_COMMAND_STATE: str
CONF_COMMAND_STOP: str
CONF_CONDITION: str
CONF_CONDITIONS: str
CONF_CONTINUE_ON_TIMEOUT: str
CONF_COUNT: str
CONF_COVERS: str
CONF_CURRENCY: str
CONF_CUSTOMIZE: str
CONF_CUSTOMIZE_DOMAIN: str
CONF_CUSTOMIZE_GLOB: str
CONF_DEFAULT: str
CONF_DELAY: str
CONF_DELAY_TIME: str
CONF_DESCRIPTION: str
CONF_DEVICE: str
CONF_DEVICES: str
CONF_DEVICE_CLASS: str
CONF_DEVICE_ID: str
CONF_DISARM_AFTER_TRIGGER: str
CONF_DISCOVERY: str
CONF_DISKS: str
CONF_DISPLAY_CURRENCY: str
CONF_DISPLAY_OPTIONS: str
CONF_DOMAIN: str
CONF_DOMAINS: str
CONF_EFFECT: str
CONF_ELEVATION: str
CONF_EMAIL: str
CONF_ENTITIES: str
CONF_ENTITY_ID: str
CONF_ENTITY_NAMESPACE: str
CONF_ENTITY_PICTURE_TEMPLATE: str
CONF_EVENT: str
CONF_EVENT_DATA: str
CONF_EVENT_DATA_TEMPLATE: str
CONF_EXCLUDE: str
CONF_EXTERNAL_URL: str
CONF_FILENAME: str
CONF_FILE_PATH: str
CONF_FOR: str
CONF_FORCE_UPDATE: str
CONF_FRIENDLY_NAME: str
CONF_FRIENDLY_NAME_TEMPLATE: str
CONF_HEADERS: str
CONF_HOST: str
CONF_HOSTS: str
CONF_HS: str
CONF_ICON: str
CONF_ICON_TEMPLATE: str
CONF_ID: str
CONF_INCLUDE: str
CONF_INTERNAL_URL: str
CONF_IP_ADDRESS: str
CONF_LATITUDE: str
CONF_LEGACY_TEMPLATES: str
CONF_LIGHTS: str
CONF_LONGITUDE: str
CONF_MAC: str
CONF_MAXIMUM: str
CONF_MEDIA_DIRS: str
CONF_METHOD: str
CONF_MINIMUM: str
CONF_MODE: str
CONF_MONITORED_CONDITIONS: str
CONF_MONITORED_VARIABLES: str
CONF_NAME: str
CONF_OFFSET: str
CONF_OPTIMISTIC: str
CONF_PACKAGES: str
CONF_PARAMS: str
CONF_PASSWORD: str
CONF_PATH: str
CONF_PAYLOAD: str
CONF_PAYLOAD_OFF: str
CONF_PAYLOAD_ON: str
CONF_PENDING_TIME: str
CONF_PIN: str
CONF_PLATFORM: str
CONF_PORT: str
CONF_PREFIX: str
CONF_PROFILE_NAME: str
CONF_PROTOCOL: str
CONF_PROXY_SSL: str
CONF_QUOTE: str
CONF_RADIUS: str
CONF_RECIPIENT: str
CONF_REGION: str
CONF_REPEAT: str
CONF_RESOURCE: str
CONF_RESOURCES: str
CONF_RESOURCE_TEMPLATE: str
CONF_RGB: str
CONF_ROOM: str
CONF_SCAN_INTERVAL: str
CONF_SCENE: str
CONF_SELECTOR: str
CONF_SENDER: str
CONF_SENSORS: str
CONF_SENSOR_TYPE: str
CONF_SEQUENCE: str
CONF_SERVICE: str
CONF_SERVICE_DATA: str
CONF_SERVICE_TEMPLATE: str
CONF_SHOW_ON_MAP: str
CONF_SLAVE: str
CONF_SOURCE: str
CONF_SSL: str
CONF_STATE: str
CONF_STATE_TEMPLATE: str
CONF_STRUCTURE: str
CONF_SWITCHES: str
CONF_TARGET: str
CONF_TEMPERATURE_UNIT: str
CONF_TIMEOUT: str
CONF_TIME_ZONE: str
CONF_TOKEN: str
CONF_TRIGGER_TIME: str
CONF_TTL: str
CONF_TYPE: str
CONF_UNIQUE_ID: str
CONF_UNIT_OF_MEASUREMENT: str
CONF_UNIT_SYSTEM: str
CONF_UNTIL: str
CONF_URL: str
CONF_USERNAME: str
CONF_VALUE_TEMPLATE: str
CONF_VARIABLES: str
CONF_VERIFY_SSL: str
CONF_WAIT_FOR_TRIGGER: str
CONF_WAIT_TEMPLATE: str
CONF_WEBHOOK_ID: str
CONF_WEEKDAY: str
CONF_WHILE: str
CONF_WHITELIST: str
CONF_ALLOWLIST_EXTERNAL_DIRS: str
LEGACY_CONF_WHITELIST_EXTERNAL_DIRS: str
CONF_WHITE_VALUE: str
CONF_XY: str
CONF_ZONE: str
EVENT_CALL_SERVICE: str
EVENT_COMPONENT_LOADED: str
EVENT_CORE_CONFIG_UPDATE: str
EVENT_HOMEASSISTANT_CLOSE: str
EVENT_HOMEASSISTANT_START: str
EVENT_HOMEASSISTANT_STARTED: str
EVENT_HOMEASSISTANT_STOP: str
EVENT_HOMEASSISTANT_FINAL_WRITE: str
EVENT_LOGBOOK_ENTRY: str
EVENT_SERVICE_REGISTERED: str
EVENT_SERVICE_REMOVED: str
EVENT_STATE_CHANGED: str
EVENT_THEMES_UPDATED: str
EVENT_TIMER_OUT_OF_SYNC: str
EVENT_TIME_CHANGED: str
DEVICE_CLASS_BATTERY: str
DEVICE_CLASS_CO: str
DEVICE_CLASS_CO2: str
DEVICE_CLASS_HUMIDITY: str
DEVICE_CLASS_ILLUMINANCE: str
DEVICE_CLASS_SIGNAL_STRENGTH: str
DEVICE_CLASS_TEMPERATURE: str
DEVICE_CLASS_TIMESTAMP: str
DEVICE_CLASS_PRESSURE: str
DEVICE_CLASS_POWER: str
DEVICE_CLASS_CURRENT: str
DEVICE_CLASS_ENERGY: str
DEVICE_CLASS_POWER_FACTOR: str
DEVICE_CLASS_VOLTAGE: str
STATE_ON: str
STATE_OFF: str
STATE_HOME: str
STATE_NOT_HOME: str
STATE_UNKNOWN: str
STATE_OPEN: str
STATE_OPENING: str
STATE_CLOSED: str
STATE_CLOSING: str
STATE_PLAYING: str
STATE_PAUSED: str
STATE_IDLE: str
STATE_STANDBY: str
STATE_ALARM_DISARMED: str
STATE_ALARM_ARMED_HOME: str
STATE_ALARM_ARMED_AWAY: str
STATE_ALARM_ARMED_NIGHT: str
STATE_ALARM_ARMED_CUSTOM_BYPASS: str
STATE_ALARM_PENDING: str
STATE_ALARM_ARMING: str
STATE_ALARM_DISARMING: str
STATE_ALARM_TRIGGERED: str
STATE_LOCKED: str
STATE_UNLOCKED: str
STATE_UNAVAILABLE: str
STATE_OK: str
STATE_PROBLEM: str
ATTR_ATTRIBUTION: str
ATTR_CREDENTIALS: str
ATTR_NOW: str
ATTR_DATE: str
ATTR_TIME: str
ATTR_SECONDS: str
ATTR_DOMAIN: str
ATTR_SERVICE: str
ATTR_SERVICE_DATA: str
ATTR_ID: str
ATTR_NAME: str
ATTR_ENTITY_ID: str
ATTR_AREA_ID: str
ATTR_DEVICE_ID: str
ATTR_FRIENDLY_NAME: str
ATTR_ENTITY_PICTURE: str
ATTR_ICON: str
ATTR_UNIT_OF_MEASUREMENT: str
CONF_UNIT_SYSTEM_METRIC: str
CONF_UNIT_SYSTEM_IMPERIAL: str
ATTR_VOLTAGE: str
ATTR_LOCATION: str
ATTR_MODE: str
ATTR_BATTERY_CHARGING: str
ATTR_BATTERY_LEVEL: str
ATTR_WAKEUP: str
ATTR_CODE: str
ATTR_CODE_FORMAT: str
ATTR_COMMAND: str
ATTR_ARMED: str
ATTR_LOCKED: str
ATTR_TRIPPED: str
ATTR_LAST_TRIP_TIME: str
ATTR_HIDDEN: str
ATTR_LATITUDE: str
ATTR_LONGITUDE: str
ATTR_GPS_ACCURACY: str
ATTR_ASSUMED_STATE: str
ATTR_STATE: str
ATTR_EDITABLE: str
ATTR_OPTION: str
ATTR_RESTORED: str
ATTR_SUPPORTED_FEATURES: str
ATTR_DEVICE_CLASS: str
ATTR_TEMPERATURE: str
POWER_WATT: str
POWER_KILO_WATT: str
VOLT: str
ENERGY_WATT_HOUR: str
ENERGY_KILO_WATT_HOUR: str
ELECTRICAL_CURRENT_AMPERE: str
ELECTRICAL_VOLT_AMPERE: str
DEGREE: str
CURRENCY_EURO: str
CURRENCY_DOLLAR: str
CURRENCY_CENT: str
TEMP_CELSIUS: str
TEMP_FAHRENHEIT: str
TEMP_KELVIN: str
TIME_MICROSECONDS: str
TIME_MILLISECONDS: str
TIME_SECONDS: str
TIME_MINUTES: str
TIME_HOURS: str
TIME_DAYS: str
TIME_WEEKS: str
TIME_MONTHS: str
TIME_YEARS: str
LENGTH_MILLIMETERS: str
LENGTH_CENTIMETERS: str
LENGTH_METERS: str
LENGTH_KILOMETERS: str
LENGTH_INCHES: str
LENGTH_FEET: str
LENGTH_YARD: str
LENGTH_MILES: str
FREQUENCY_HERTZ: str
FREQUENCY_GIGAHERTZ: str
PRESSURE_PA: str
PRESSURE_HPA: str
PRESSURE_BAR: str
PRESSURE_MBAR: str
PRESSURE_INHG: str
PRESSURE_PSI: str
VOLUME_LITERS: str
VOLUME_MILLILITERS: str
VOLUME_CUBIC_METERS: str
VOLUME_CUBIC_FEET: str
VOLUME_GALLONS: str
VOLUME_FLUID_OUNCE: str
VOLUME_FLOW_RATE_CUBIC_METERS_PER_HOUR: str
VOLUME_FLOW_RATE_CUBIC_FEET_PER_MINUTE: str
AREA_SQUARE_METERS: str
MASS_GRAMS: str
MASS_KILOGRAMS: str
MASS_MILLIGRAMS: str
MASS_MICROGRAMS: str
MASS_OUNCES: str
MASS_POUNDS: str
CONDUCTIVITY: str
LIGHT_LUX: str
UV_INDEX: str
PERCENTAGE: str
IRRADIATION_WATTS_PER_SQUARE_METER: str
PRECIPITATION_MILLIMETERS_PER_HOUR: str
CONCENTRATION_MICROGRAMS_PER_CUBIC_METER: str
CONCENTRATION_MILLIGRAMS_PER_CUBIC_METER: str
CONCENTRATION_PARTS_PER_CUBIC_METER: str
CONCENTRATION_PARTS_PER_MILLION: str
CONCENTRATION_PARTS_PER_BILLION: str
SPEED_MILLIMETERS_PER_DAY: str
SPEED_INCHES_PER_DAY: str
SPEED_METERS_PER_SECOND: str
SPEED_INCHES_PER_HOUR: str
SPEED_KILOMETERS_PER_HOUR: str
SPEED_MILES_PER_HOUR: str
SIGNAL_STRENGTH_DECIBELS: str
SIGNAL_STRENGTH_DECIBELS_MILLIWATT: str
DATA_BITS: str
DATA_KILOBITS: str
DATA_MEGABITS: str
DATA_GIGABITS: str
DATA_BYTES: str
DATA_KILOBYTES: str
DATA_MEGABYTES: str
DATA_GIGABYTES: str
DATA_TERABYTES: str
DATA_PETABYTES: str
DATA_EXABYTES: str
DATA_ZETTABYTES: str
DATA_YOTTABYTES: str
DATA_KIBIBYTES: str
DATA_MEBIBYTES: str
DATA_GIBIBYTES: str
DATA_TEBIBYTES: str
DATA_PEBIBYTES: str
DATA_EXBIBYTES: str
DATA_ZEBIBYTES: str
DATA_YOBIBYTES: str
DATA_RATE_BITS_PER_SECOND: str
DATA_RATE_KILOBITS_PER_SECOND: str
DATA_RATE_MEGABITS_PER_SECOND: str
DATA_RATE_GIGABITS_PER_SECOND: str
DATA_RATE_BYTES_PER_SECOND: str
DATA_RATE_KILOBYTES_PER_SECOND: str
DATA_RATE_MEGABYTES_PER_SECOND: str
DATA_RATE_GIGABYTES_PER_SECOND: str
DATA_RATE_KIBIBYTES_PER_SECOND: str
DATA_RATE_MEBIBYTES_PER_SECOND: str
DATA_RATE_GIBIBYTES_PER_SECOND: str
SERVICE_HOMEASSISTANT_STOP: str
SERVICE_HOMEASSISTANT_RESTART: str
SERVICE_TURN_ON: str
SERVICE_TURN_OFF: str
SERVICE_TOGGLE: str
SERVICE_RELOAD: str
SERVICE_VOLUME_UP: str
SERVICE_VOLUME_DOWN: str
SERVICE_VOLUME_MUTE: str
SERVICE_VOLUME_SET: str
SERVICE_MEDIA_PLAY_PAUSE: str
SERVICE_MEDIA_PLAY: str
SERVICE_MEDIA_PAUSE: str
SERVICE_MEDIA_STOP: str
SERVICE_MEDIA_NEXT_TRACK: str
SERVICE_MEDIA_PREVIOUS_TRACK: str
SERVICE_MEDIA_SEEK: str
SERVICE_REPEAT_SET: str
SERVICE_SHUFFLE_SET: str
SERVICE_ALARM_DISARM: str
SERVICE_ALARM_ARM_HOME: str
SERVICE_ALARM_ARM_AWAY: str
SERVICE_ALARM_ARM_NIGHT: str
SERVICE_ALARM_ARM_CUSTOM_BYPASS: str
SERVICE_ALARM_TRIGGER: str
SERVICE_LOCK: str
SERVICE_UNLOCK: str
SERVICE_OPEN: str
SERVICE_CLOSE: str
SERVICE_CLOSE_COVER: str
SERVICE_CLOSE_COVER_TILT: str
SERVICE_OPEN_COVER: str
SERVICE_OPEN_COVER_TILT: str
SERVICE_SET_COVER_POSITION: str
SERVICE_SET_COVER_TILT_POSITION: str
SERVICE_STOP_COVER: str
SERVICE_STOP_COVER_TILT: str
SERVICE_TOGGLE_COVER_TILT: str
SERVICE_SELECT_OPTION: str
SERVER_PORT: int
URL_ROOT: str
URL_API: str
URL_API_STREAM: str
URL_API_CONFIG: str
URL_API_DISCOVERY_INFO: str
URL_API_STATES: str
URL_API_STATES_ENTITY: str
URL_API_EVENTS: str
URL_API_EVENTS_EVENT: str
URL_API_SERVICES: str
URL_API_SERVICES_SERVICE: str
URL_API_COMPONENTS: str
URL_API_ERROR_LOG: str
URL_API_LOG_OUT: str
URL_API_TEMPLATE: str
HTTP_OK: int
HTTP_CREATED: int
HTTP_ACCEPTED: int
HTTP_MOVED_PERMANENTLY: int
HTTP_BAD_REQUEST: int
HTTP_UNAUTHORIZED: int
HTTP_FORBIDDEN: int
HTTP_NOT_FOUND: int
HTTP_METHOD_NOT_ALLOWED: int
HTTP_UNPROCESSABLE_ENTITY: int
HTTP_TOO_MANY_REQUESTS: int
HTTP_INTERNAL_SERVER_ERROR: int
HTTP_BAD_GATEWAY: int
HTTP_SERVICE_UNAVAILABLE: int
HTTP_BASIC_AUTHENTICATION: str
HTTP_DIGEST_AUTHENTICATION: str
HTTP_HEADER_X_REQUESTED_WITH: str
CONTENT_TYPE_JSON: str
CONTENT_TYPE_MULTIPART: str
CONTENT_TYPE_TEXT_PLAIN: str
RESTART_EXIT_CODE: int
UNIT_NOT_RECOGNIZED_TEMPLATE: str
LENGTH: str
MASS: str
PRESSURE: str
VOLUME: str
TEMPERATURE: str
SPEED_MS: str
ILLUMINANCE: str
WEEKDAYS: Any
PRECISION_WHOLE: int
PRECISION_HALVES: float
PRECISION_TENTHS: float
CLOUD_NEVER_EXPOSED_ENTITIES: Any
CAST_APP_ID_HOMEASSISTANT: str
