from homeassistant.helpers import device_registry as dev_reg, entity_registry as ent_reg
from typing import Any

class PermissionLookup:
    entity_registry: ent_reg.EntityRegistry = ...
    device_registry: dev_reg.DeviceRegistry = ...
    def __init__(self, entity_registry: Any, device_registry: Any) -> None: ...
    def __lt__(self, other: Any) -> Any: ...
    def __le__(self, other: Any) -> Any: ...
    def __gt__(self, other: Any) -> Any: ...
    def __ge__(self, other: Any) -> Any: ...
